#!/bin/bash
set -e
if [ ! -d test_output ]; then
    mkdir test_output
fi

#Nucleotide-nucleotide BLAST (megablast)
perl remote_blast_client.pl -i test_input/test_input_megablast.fasta -b megablast -d nr -o test_output/results_megablast.txt

#Nucleotide-nucleotide BLAST (blastn)
perl remote_blast_client.pl -i test_input/test_input_dna.fasta -b blastn -d nr -o test_output/results_blastn.txt -accession T

#Protein-protein BLAST (blastp)
perl remote_blast_client.pl -i test_input/test_input_protein.fasta -b blastp -d nr -o test_output/results_blastp.txt

#Translated query vs protein database (blastx)
perl remote_blast_client.pl -i test_input/test_input_dna.fasta -b blastx -d nr -o test_output/results_blastx.txt

#Protein query vs translated database (tblastn)
perl remote_blast_client.pl -i test_input/test_input_protein.fasta -b tblastn -d nr -o test_output/results_tblastn.txt

#Translated query vs. translated database (tblastx)
perl remote_blast_client.pl -i test_input/test_input_dna.fasta -b tblastx -d nr -o test_output/results_tblastx.txt

#Nucleotide-nucleotide BLAST (blastn) using XML parsing
perl remote_blast_client.pl -i test_input/test_input_dna.fasta -b blastn -d nr -o test_output/results_xml_parse_blastn.txt -accession T -xml T -hsp_label T -hsps_per_hit 1

#Protein-protein BLAST (blastp) using XML parsing
perl remote_blast_client.pl -i test_input/test_input_protein.fasta -b blastp -d nr -o test_output/results_xml_parse_blastp.txt -xml T -hsp_label T

#Translated query vs protein database (blastx) using XML parsing
perl remote_blast_client.pl -i test_input/test_input_dna.fasta -b blastx -d nr -o test_output/results_xml_parse_blastx.txt -xml T -hsp_label F

#Protein query vs translated database (tblastn) using XML parsing
perl remote_blast_client.pl -i test_input/test_input_protein.fasta -b tblastn -d nr -o test_output/results_xml_parse_tblastn.txt -xml T -hsp_label F

#Translated query vs. translated database (tblastx) using XML parsing
perl remote_blast_client.pl -i test_input/test_input_dna.fasta -b tblastx -d nr -o test_output/results_xml_parse_tblastx.txt -xml T -hsp_label T

#compare new output to sample output
new_output=test_output
old_output=sample_output
new_files=($( find $new_output -type f -print0 | perl -ne 'my @files = split(/\0/, $_); foreach(@files) { if (!($_ =~ m/\.svn/)) {print "$_\n";}}'))
for (( i=0; i<${#new_files[@]}; i++ ));
do
    old_file=${old_output}`echo "${new_files[$i]}" | perl -nl -e 's/^[^\/]+//;' -e 'print $_'`
    echo "Comparing ${old_file} to ${new_files[$i]}"
    set +e
    diff -u $old_file ${new_files[$i]}
    if [ $? -eq 0 ]; then
	echo "No differences found"
    fi
    set -e
done
